@@ -1,10 +1,8 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 import argparse
 import logging
 import sys
-import tempfile
 import traceback
 from pathlib import Path
 
@@ -15,7 +13,6 @@ from cdp_backend.file_store.functions import upload_file
 from cdp_backend.pipeline import event_gather_pipeline as pipeline
 from cdp_backend.pipeline.ingestion_models import EventIngestionModel
 from cdp_backend.pipeline.pipeline_config import EventGatherPipelineConfig
-from cdp_backend.utils.file_utils import resource_copy
 
 ###############################################################################
 
@@ -56,40 +53,28 @@ def main() -> None:
         args = Args()
 
         # Read pipeline config
-        with open(args.event_gather_config_file, "r") as open_resource:
-            config = EventGatherPipelineConfig.from_json(  # type: ignore
-                open_resource.read()
-            )
+        with open(args.event_gather_config_file) as open_resource:
+            config = EventGatherPipelineConfig.from_json(open_resource.read())
 
         log.info("Parsing event details...")
         # Convert event details file to EventIngestionModel
-        with open(args.event_details_file, "r") as open_resource:
-            ingestion_model = EventIngestionModel.from_json(  # type: ignore
-                open_resource.read()
-            )
+        with open(args.event_details_file) as open_resource:
+            ingestion_model = EventIngestionModel.from_json(open_resource.read())
 
             for session in ingestion_model.sessions:
                 # Copy if remote resource, otherwise use local file uri
-                fs, path = url_to_fs(session.video_uri)
-                if not isinstance(fs, LocalFileSystem):
-                    # Create tmp directory to save file in
-                    dirpath = tempfile.mkdtemp()
-                    dst = Path(dirpath)
+                fs, _ = url_to_fs(session.video_uri)
+                if isinstance(fs, LocalFileSystem):
+                    # Upload video file to file store
+                    log.info(f"Uploading {session.video_uri}...")
+                    video_uri = upload_file(
+                        credentials_file=config.google_credentials_file,
+                        bucket=config.validated_gcs_bucket_name,
+                        filepath=session.video_uri,
+                    )
 
-                    filepath = resource_copy(uri=session.video_uri, dst=dst)
-                else:
-                    filepath = session.video_uri
-
-                # Upload video file to file store
-                log.info(f"Uploading {session.video_uri}...")
-                video_uri = upload_file(
-                    credentials_file=config.google_credentials_file,
-                    bucket=config.validated_gcs_bucket_name,
-                    filepath=filepath,
-                )
-
-                # Replace video_uri of session
-                session.video_uri = video_uri
+                    # Replace video_uri of session
+                    session.video_uri = video_uri
 
         # Create event gather pipeline flow
         log.info("Beginning processing...")
