@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import http.client
 import logging
 from datetime import datetime, timedelta
 from importlib import import_module
@@ -10,6 +11,7 @@ from pathlib import Path
 from typing import Callable, NamedTuple
 from uuid import uuid4
 
+import backoff
 from aiohttp.client_exceptions import ClientResponseError
 from fireo.fields.errors import FieldValidationFailed, InvalidFieldType, RequiredField
 from gcsfs import GCSFileSystem
@@ -55,6 +57,19 @@ def import_get_events_func(func_path: str) -> Callable:
     return getattr(mod, func_name)
 
 
+@backoff.on_exception(
+    backoff.expo,
+    http.client.HTTPException,
+    max_tries=3,
+)
+def get_events_with_backoff(
+    func: Callable,
+    start_dt: datetime,
+    end_dt: datetime,
+) -> list[ingestion_models.EventIngestionModel]:
+    return func(from_dt=start_dt, to_dt=end_dt)
+
+
 def create_event_gather_flow(
     config: EventGatherPipelineConfig,
     from_dt: str | datetime | None = None,
@@ -118,16 +133,18 @@ def create_event_gather_flow(
             events = prefetched_events
 
         else:
-            events = get_events_func(
-                from_dt=from_datetime,
-                to_dt=to_datetime,
+            # Run the get events
+            events = get_events_with_backoff(
+                get_events_func,
+                start_dt=from_datetime,
+                end_dt=to_datetime,
             )
 
         # Safety measure catch
         if events is None:
             events = []
-        log.info(f"Processing {len(events)} events.")
 
+        log.info(f"Processing {len(events)} events.")
         for event in events:
             session_processing_results: list[SessionProcessingResult] = []
             for session in event.sessions:
@@ -294,7 +311,7 @@ def get_session_content_hash(
 
 
 @task(nout=3)
-def convert_video_and_handle_host(
+def convert_video_and_handle_host(  # noqa: C901
     video_filepath: str,
     session: Session,
     credentials_file: str,
@@ -328,6 +345,8 @@ def convert_video_and_handle_host(
     """
     # Get file extension
     ext = Path(video_filepath).suffix.lower()
+    log.info(f"Original video uri: '{session.video_uri}'")
+    log.info(f"Handling video conversion and hosting for video: '{video_filepath}'")
 
     trim_video = bool(session.video_start_time or session.video_end_time)
 
@@ -373,6 +392,7 @@ def convert_video_and_handle_host(
 
     # Store if the original host isn't https
     elif not is_secure_uri(session.video_uri):
+        log.info("Handling secure video URI")
         try:
             resource_uri = try_url(session.video_uri)
         except LookupError:
@@ -388,7 +408,17 @@ def convert_video_and_handle_host(
                 hosted_video_media_url = resource_uri
             else:
                 cdp_will_host = True
+
+    # Try with www
+    elif not resource_exists(session.video_uri):
+        log.info("Handling www URL problems")
+        www_url = session.video_uri.replace("://", "://www.")
+        if resource_exists(www_url):
+            hosted_video_media_url = www_url
+
+    # All good
     else:
+        log.info(f"Video URI '{session.video_uri}' passed all checks.")
         hosted_video_media_url = session.video_uri
 
     # Get unique session identifier
@@ -411,6 +441,7 @@ def convert_video_and_handle_host(
             uri=hosted_video_uri,
         )
 
+    log.info(f"Verified video URL: '{hosted_video_media_url}")
     return video_filepath, hosted_video_media_url, session_content_hash
 
 
@@ -1034,7 +1065,7 @@ def _calculate_in_majority(
     return None
 
 
-@task
+@task(max_retries=2, retry_delay=timedelta(seconds=60))
 def store_event_processing_results(  # noqa: C901
     event: EventIngestionModel,
     session_processing_results: list[SessionProcessingResult],
