@@ -1,10 +1,11 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
+
+from __future__ import annotations
 
 import random
 from bisect import bisect_left
 from datetime import datetime, timedelta
-from typing import Any, List
+from typing import Any
 
 from ..database.constants import (
     EventMinutesItemDecision,
@@ -54,27 +55,38 @@ SESSIONS = [
     (
         "https://video.seattle.gov/media/council/council_010421_2022101V.mp4",
         "https://www.seattlechannel.org/documents/seattlechannel/closedcaption/2021/council_010421_2022101.vtt",  # noqa
+        None,
+        None,
     ),
     (
         "https://video.seattle.gov/media/council/council_113020_2022091V.mp4",
         "https://www.seattlechannel.org/documents/seattlechannel/closedcaption/2020/council_113020_2022091.vtt",  # noqa
+        "1",
+        "25:25",
     ),
     (
         "https://video.seattle.gov/media/council/council_112320_2022089V.mp4",
         "https://www.seattlechannel.org/documents/seattlechannel/closedcaption/2020/brief_112320_2012089.vtt",  # noqa
+        None,
+        "2:58:14",
     ),
     (
         "https://video.seattle.gov/media/council/council_110920_2022085V.mp4",
         "https://www.seattlechannel.org/documents/seattlechannel/closedcaption/2020/council_110920_2022085.vtt",  # noqa
+        "1",
+        None,
+    ),
+    (
+        "https://video.seattle.gov/media/council/council_101220_2022077V.mp4",
+        None,
+        None,
+        None,
     ),
-    ("https://video.seattle.gov/media/council/council_101220_2022077V.mp4", None),
 ]
 
 
 def _get_example_person(seat_num: int) -> Person:
-    """
-    Create a fake example person
-    """
+    """Create a fake example person."""
     # Create a list of roles
     roles = [
         Role(title=RoleTitle.COUNCILMEMBER, body=Body(name="Example Committee")),
@@ -106,9 +118,7 @@ def _get_example_person(seat_num: int) -> Person:
 
 
 def _get_example_event() -> EventIngestionModel:
-    """
-    Create a fake example event data
-    """
+    """Create a fake example event data."""
     # Create a body for the event
     body = Body(
         name=f"Example Committee {random.randint(*RAND_BODY_RANGE)}",
@@ -121,6 +131,8 @@ def _get_example_event() -> EventIngestionModel:
             session_datetime=datetime.utcnow() + (i * timedelta(hours=3)),
             session_index=i,
             video_uri=session[0],
+            video_start_time=session[2],
+            video_end_time=session[3],
             caption_uri=session[1],
         )
         for i, session in enumerate(random.sample(SESSIONS, random.randint(1, 3)))
@@ -223,7 +235,7 @@ def _get_example_event() -> EventIngestionModel:
     )
 
 
-def get_events(**kwargs: Any) -> List[EventIngestionModel]:
+def get_events(**kwargs: Any) -> list[EventIngestionModel]:
     """
     A mock get_events function that will generate entirely random events
     based off a set of permutation settings.
@@ -243,7 +255,7 @@ RANDOM_FLOW_CONFIG = EventGatherPipelineConfig(
 RANDOM_FLOW_CONFIG._validated_gcs_bucket_name = ""
 
 
-def min_get_events(**kwargs: Any) -> List[EventIngestionModel]:
+def min_get_events(**kwargs: Any) -> list[EventIngestionModel]:
     event = EXAMPLE_MINIMAL_EVENT
     event.sessions[0].session_datetime = datetime(2019, 4, 13)
     return [event]
@@ -257,7 +269,7 @@ MINIMAL_FLOW_CONFIG = EventGatherPipelineConfig(
 MINIMAL_FLOW_CONFIG._validated_gcs_bucket_name = ""
 
 
-def filled_get_events(**kwargs: Any) -> List[EventIngestionModel]:
+def filled_get_events(**kwargs: Any) -> list[EventIngestionModel]:
     event = EXAMPLE_FILLED_EVENT
     return [event]
 
@@ -270,7 +282,7 @@ FILLED_FLOW_CONFIG = EventGatherPipelineConfig(
 FILLED_FLOW_CONFIG._validated_gcs_bucket_name = ""
 
 
-def many_get_events(**kwargs: Any) -> List[EventIngestionModel]:
+def many_get_events(**kwargs: Any) -> list[EventIngestionModel]:
     event = EXAMPLE_MINIMAL_EVENT
     return [event] * 4
 
