@@ -1,11 +1,10 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 from dataclasses import dataclass
 from datetime import datetime
 from typing import List, Optional
 
-from dataclasses_json import dataclass_json
+from dataclasses_json import DataClassJsonMixin
 
 ###############################################################################
 # Annotation Definitions
@@ -14,25 +13,18 @@ from dataclasses_json import dataclass_json
 # Docstrings for constants go _after_ the constant.
 
 
-@dataclass_json
 @dataclass
-class WordAnnotations:
-    """
-    Annotations that can appear on an individual word level.
-    """
+class WordAnnotations(DataClassJsonMixin):
+    """Annotations that can appear on an individual word level."""
 
 
-@dataclass_json
 @dataclass
-class SentenceAnnotations:
-    """
-    Annotations that can appear on an individual sentence level.
-    """
+class SentenceAnnotations(DataClassJsonMixin):
+    """Annotations that can appear on an individual sentence level."""
 
 
-@dataclass_json
 @dataclass
-class SectionAnnotation:
+class SectionAnnotation(DataClassJsonMixin):
     """
     A section annotation used for topic segmentation and minutes item alignment.
 
@@ -69,7 +61,7 @@ class SectionAnnotation:
     ...         name="Public Comment",
     ...         start_sentence_index=12,
     ...         stop_sentence_index=87,
-    ...         generator="Jackson Maxfield Brown",
+    ...         generator="Eva Maxfield Brown",
     ...     ),
     ...     SectionAnnotation(
     ...         name="CB 120121",
@@ -88,12 +80,9 @@ class SectionAnnotation:
     description: Optional[str] = None
 
 
-@dataclass_json
 @dataclass
-class TranscriptAnnotations:
-    """
-    Annotations that can appear (but are not guaranteed) for the whole transcript.
-    """
+class TranscriptAnnotations(DataClassJsonMixin):
+    """Annotations that can appear (but are not guaranteed) for the whole transcript."""
 
     sections: Optional[List[SectionAnnotation]] = None
 
@@ -101,9 +90,8 @@ class TranscriptAnnotations:
 ###############################################################################
 
 
-@dataclass_json
 @dataclass
-class Word:
+class Word(DataClassJsonMixin):
     """
     Data for a word in a transcript.
 
@@ -129,9 +117,8 @@ class Word:
     annotations: Optional[WordAnnotations] = None
 
 
-@dataclass_json
 @dataclass
-class Sentence:
+class Sentence(DataClassJsonMixin):
     """
     Data for a sentence in a transcript.
 
@@ -169,9 +156,8 @@ class Sentence:
     annotations: Optional[SentenceAnnotations] = None
 
 
-@dataclass_json
 @dataclass
-class Transcript:
+class Transcript(DataClassJsonMixin):
     """
     Transcript model for all transcripts in CDP databases / filestores.
 
@@ -218,6 +204,7 @@ class Transcript:
     annotations: Optional[TranscriptAnnotations] = None
 
     def __repr__(self) -> str:
+        """Print out shortform transcript details."""
         output = "Transcript("
 
         # Use vars to maintain subclassing
@@ -241,7 +228,7 @@ class Transcript:
 
 
 EXAMPLE_TRANSCRIPT = Transcript(
-    generator="JacksonGen -- Lib Version: 0.0.0",
+    generator="EvaGen -- Lib Version: 0.0.0",
     confidence=0.93325,
     session_datetime=datetime(2021, 1, 10, 15).isoformat(),
     created_datetime=datetime.utcnow().isoformat(),
@@ -252,7 +239,7 @@ EXAMPLE_TRANSCRIPT = Transcript(
             confidence=0.9,
             start_time=0.0,
             end_time=1.0,
-            speaker_name="Jackson Maxfield Brown",
+            speaker_name="Eva Maxfield Brown",
             speaker_index=0,
             words=[
                 Word(
@@ -299,7 +286,7 @@ EXAMPLE_TRANSCRIPT = Transcript(
                 name="Call to Order",
                 start_sentence_index=0,
                 stop_sentence_index=2,
-                generator="Jackson Maxfield Brown",
+                generator="Eva Maxfield Brown",
             )
         ],
     ),
